@@ -1,9 +1,5 @@
-/* doc in vfprintf.c */
-
-/* This code created by modifying vsprintf.c so copyright inherited. */
-
 /*
- * Copyright (c) 1990 The Regents of the University of California.
+ * Copyright (c) 1990, 2007 The Regents of the University of California.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms are permitted
@@ -18,6 +14,7 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
+/* doc in vfprintf.c */
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "%W% (Berkeley) %G%";
@@ -27,48 +24,46 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 #include <reent.h>
 #include <stdio.h>
 #include <limits.h>
-#ifdef _HAVE_STDC
 #include <stdarg.h>
-#else
-#include <varargs.h>
-#endif
+#include <errno.h>
+
+#ifndef _REENT_ONLY
 
 int
-vsnprintf (str, size, fmt, ap)
-     char *str;
-     size_t size;
-     char _CONST *fmt;
-     va_list ap;
+_DEFUN(vsnprintf, (str, size, fmt, ap),
+       char *str        _AND
+       size_t size      _AND
+       const char *fmt _AND
+       va_list ap)
+{
+  return _vsnprintf_r (_REENT, str, size, fmt, ap);
+}
+
+#endif /* !_REENT_ONLY */
+
+int
+_DEFUN(_vsnprintf_r, (ptr, str, size, fmt, ap),
+       struct _reent *ptr _AND
+       char *str          _AND
+       size_t size        _AND
+       const char *fmt   _AND
+       va_list ap)
 {
   int ret;
   FILE f;
 
+  if (size > INT_MAX)
+    {
+      ptr->_errno = EOVERFLOW;
+      return EOF;
+    }
   f._flags = __SWR | __SSTR;
   f._bf._base = f._p = (unsigned char *) str;
   f._bf._size = f._w = (size > 0 ? size - 1 : 0);
-  f._data = _REENT;
-  ret = vfprintf (&f, fmt, ap);
-  if (size > 0)
-    *f._p = 0;
-  return ret;
-}
-
-int
-vsnprintf_r (ptr, str, size, fmt, ap)
-     struct _reent *ptr;
-     char *str;
-     size_t size;
-     char _CONST *fmt;
-     va_list ap;
-{
-  int ret;
-  FILE f;
-
-  f._flags = __SWR | __SSTR;
-  f._bf._base = f._p = (unsigned char *) str;
-  f._bf._size = f._w = (size > 0 ? size - 1 : 0);
-  f._data = ptr;
-  ret = vfprintf (&f, fmt, ap);
+  f._file = -1;  /* No file. */
+  ret = _vfprintf_r (ptr, &f, fmt, ap);
+  if (ret < EOF)
+    ptr->_errno = EOVERFLOW;
   if (size > 0)
     *f._p = 0;
   return ret;
