@@ -19,24 +19,24 @@ getlogin ()
       || ((tty = ttyname (2)) == 0))
     return 0;
 
-  if ((utmp_fd = _open (UTMP_FILE, O_RDONLY)) == -1)
+  if ((utmp_fd = open (UTMP_FILE, O_RDONLY)) == -1)
     return 0;
 
   if (!strncmp (tty, "/dev/", 5))
     tty += 5;
 
-  while (_read (utmp_fd, &utmp_buf, sizeof (utmp_buf)) == sizeof (utmp_buf))
+  while (read (utmp_fd, &utmp_buf, sizeof (utmp_buf)) == sizeof (utmp_buf))
     {
       if (!strncmp (tty, utmp_buf.ut_line, sizeof (utmp_buf.ut_line))
 	  && utmp_buf.ut_type == USER_PROCESS)
 	{
-	  _close (utmp_fd);
+	  close (utmp_fd);
 	  memset (buf, 0, sizeof (buf));
 	  strncpy (buf, utmp_buf.ut_user, sizeof (utmp_buf.ut_user));
 	  return buf;
 	}
     }
 
-  _close (utmp_fd);
+  close (utmp_fd);
   return 0;
 }
